package com.ruoyi.mall.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.mall.domain.Bo.VipCodeBO;
import com.ruoyi.mall.domain.MallMemberUser;
import com.ruoyi.mall.domain.MallSchool;

/**
 * 用户会员Service接口
 *
 * @author ruoyi
 * @date 2023-10-12
 */
public interface IMallMemberUserService
{
    /**
     * 查询用户会员
     *
     * @param id 用户会员主键
     * @return 用户会员
     */
    public MallMemberUser selectMallMemberUserById(Long id);

    /**
     * 查询用户会员列表
     *
     * @param mallMemberUser 用户会员
     * @return 用户会员集合
     */
    public List<MallMemberUser> selectMallMemberUserList(MallMemberUser mallMemberUser);

    /**
     * 新增用户会员
     *
     * @param mallMemberUser 用户会员
     * @return 结果
     */
    public int insertMallMemberUser(MallMemberUser mallMemberUser);

    /**
     * 修改用户会员
     *
     * @param mallMemberUser 用户会员
     * @return 结果
     */
    public int updateMallMemberUser(MallMemberUser mallMemberUser);

    /**
     * 批量删除用户会员
     *
     * @param ids 需要删除的用户会员主键集合
     * @return 结果
     */
    public int deleteMallMemberUserByIds(Long[] ids);


    public void updateRate(Long userId, Integer cultureScore, Integer majorScore, String subjectType);

    /**
     * 删除用户会员信息
     *
     * @param id 用户会员主键
     * @return 结果
     */
    public int deleteMallMemberUserById(Long id);

    /**
     * 根据openid用户会员信息
     *
     * @param openid
     * @return 结果
     */
    public MallMemberUser queryByOpenid(String openid);

    /**
     * 获取海报图片
     * @param id 用户id
     * @return 结果
     */
    public AjaxResult getPoster(Long id);

    /** 生成邀请码 */
    public String getCode();

    /** 使用会员码 */
    public AjaxResult useVipCode(VipCodeBO vipCodeBO);

    /**
     * 创建用户录取率表
     */
    public void createUserRate();

    /**
     * 修改用户会员信息
     *
     * @param mallMemberUser 用户会员
     * @return 结果
     */
    public int updateMallMemberUserInfo(MallMemberUser mallMemberUser);

    /**
     * 新增系统用户
     *
     * @param mallMemberUser 用户
     * @return 结果
     */
    public AjaxResult submitUser(MallMemberUser mallMemberUser);

    /**
     * 查询用户会员
     *
     * @param sysUserId 系统用户ID
     * @return 用户会员
     */
    public MallMemberUser selectMallMemberUserBySysUserId(Long sysUserId);

    /**
     * 统计-开通未开通指南人数
     *
     * @param params 参数
     * @return 统计-开通未开通指南人数
     */
    public Map<String, Object> setIsOpenStatisticsNum(Map<String, Object> params);
}
